# Copyright (C) 2011 Adam Stein <adam@csh.rit.edu>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#------------------------------------------------------------------------
#
# Gramps modules
#
#------------------------------------------------------------------------
from gen.display.name import displayer as name_displayer
from SubstKeywords import SubstKeywords

from Enhanced_Date import Enhanced_Date

#------------------------------------------------------------------------
#
# Enhanced_SubstKeywords
#
#------------------------------------------------------------------------
class Enhanced_SubstKeywords(SubstKeywords):
    """
    The enhanced version adds the following:

    $c -> Name - FirstName LastName (NO middle name)
    $C -> Name - LastName, FirstName (NO middle name)
    $p -> Date of preferred photo
    $P -> Date of preferred photo surrounded by parenthesis
    """

    def __init__(self, database, person_handle):
        SubstKeywords.__init__(self, database, person_handle)

        person = database.get_person_from_handle(person_handle)

        name = person.get_primary_name()
        first_name = name.get_first_name().split()[0]   # Ensure first name only -- no middle name
        last_name = name.get_surname()

        self.c = first_name + " " + last_name
        self.C = last_name + ", " + first_name

        plist = person.get_media_list()

        if len(plist) > 0:
            media = database.get_object_from_handle(plist[0].ref)
            date = Enhanced_Date(media.get_date_object())
            date.set_style(Enhanced_Date.STYLE_US)

            if not date.is_empty():
                self.p = str(date)
                self.P = "(%s)" % self.p
            else:
                self.p = ""
                self.P = ""
        else:
            self.p = ""
            self.P = ""

    def replace(self, line):
        """Return a new line of text with the substitutions performed."""
        array = [ ("$n", self.n), ("$N", self.N), ("$b", self.b),
                  ("$B", self.B), ("$d", self.d), ("$D", self.D),
                  ("$i", self.i), ("$S", self.S), ("$s", self.s),
                  ("$m", self.m), ("$M", self.M), ("$c", self.c),
                  ("$C", self.C), ("$p", self.p), ("$P", self.P),
                  ("$$", "$") ]

        for (key, value) in array:
            line = line.replace(key, value)
        return line

    def replace_and_clean(self, lines):
        array = [ ("%n", self.n), ("%N", self.N), ("%b", self.b),
                  ("%B", self.B), ("%d", self.d), ("%D", self.D),
                  ("%i", self.i), ("%S", self.S), ("%s", self.s),
                  ("%m", self.m), ("%M", self.M), ("%c", self.c),
                  ("%C", self.C), ("%p", self.p), ("%P", self.P) ]

        new = []
        for line in lines:
            remove = False
            for (key, value) in array:
                if line.find(key) != -1:
                    if value:
                        line = line.replace(key, value)
                    else:
                        remove = True
            if not remove:
                new.append(self.replace(line))
        if len(new) == 0:
            return [ u"" ]
        else:
            return new

